pub fn apply_value_update(
nt: &mut NtScalar,
val: &DecodedValue,
compute_alarms: bool,
) -> boolExpand description
Apply a scalar value update from a decoded PUT body to an NtScalar.
pub fn apply_value_update(
nt: &mut NtScalar,
val: &DecodedValue,
compute_alarms: bool,
) -> boolApply a scalar value update from a decoded PUT body to an NtScalar.