GroupSource

Struct GroupSource 

pub struct GroupSource { /* private fields */ }
A Source that serves group PVs composed from multiple member PVs.

Group PV names are resolved by fetching each member PV from the underlying SourceRegistry and composing them into an NtPayload::Generic. Non-group names are not claimed.

Implementations

Source

impl GroupSource

pub fn new( sources: Arc<SourceRegistry>, groups: HashMap<String, GroupPvDef>, ) -> Self

Create a new group source backed by sources with the given group definitions.