pub struct RunningServer { /* private fields */ }Expand description
A started server: mint typed handles, then abort() to stop.
Implementations
Sourceimpl RunningServer
impl RunningServer
Sourcepub async fn pv<T: PvScalar>(&self, name: &str) -> Result<Pv<T>, PvError>
pub async fn pv<T: PvScalar>(&self, name: &str) -> Result<Pv<T>, PvError>
Mint a typed handle to any served record (handle-built or .db-loaded).
Sourcepub async fn array_pv(&self, name: &str) -> Result<PvArray, PvError>
pub async fn array_pv(&self, name: &str) -> Result<PvArray, PvError>
Mint an array handle to any served record (handle-built or .db-loaded).
pub fn store(&self) -> &Arc<SimplePvStore> ⓘ
pub fn abort(&self)